/***************/
/* Code Blocks */
/***************/

/* Scroll instead of wrap */
pre,
pre > code {
  overflow-x: scroll;
  white-space: pre;
  word-wrap: normal;
}

/* Override OS X's hidden scrollbars */
pre::-webkit-scrollbar {
  -webkit-appearance: none;
  height: 5px;
}

pre::-webkit-scrollbar-thumb {
  border-radius: 5px;
  background-color: rgba(0, 0, 0, 0.5);
  -webkit-box-shadow: 0 0 1px rgba(255, 255, 255, 0.5);
}

/*****************/
/* Documentation */
/*****************/

.documentation-title {
  background-color: rgb(225, 225, 225);
}

a.documentation-title:hover {
  background-color: rgb(245, 245, 245);
}

/***********/
/* General */
/***********/

body {
  padding-top: 25px;
  padding-bottom: 25px;
  word-wrap: break-word;
}

/*************/
/* Jumbotron */
/*************/

.jumbotron .btn {
  margin-bottom: 5px;
}

.jumbotron  h1:first-child {
  margin-top: 0;
}

/**************/
/* Pagination */
/**************/

.pagination .glyphicon-menu-left + .glyphicon-menu-left,
.pagination .glyphicon-menu-right + .glyphicon-menu-right {
  margin-left: -13px;
}

/**********/
/* Panels */
/**********/

/* Adjust vertical spacing around list groups within panels */
.panel-body h4:first-of-type {
  margin-top: 0;
}

.panel-body .list-group {
  margin-bottom: 15px;
}

.panel-body .list-group:last-of-type {
  margin-bottom: 0;
}

/* By default, Bootstrap panel footers use 'background-color: #f5f5f5' */
.panel-footer.panel-danger {
  background-color: #f2dede;
}

.panel-footer.panel-info {
  background-color: #d9edf7;
}

.panel-footer.panel-success {
  background-color: #dff0d8;
}

/****************************************/
/* Visibility on Different Screen Sizes */
/****************************************/

.show-on-mobile-block,
.show-on-mobile-inline {
  display: none;
}

@media screen and (max-width: 450px) {
  .full-width-on-mobile {
    width: 100%;
  }

  .hide-on-mobile {
    display: none;
  }

  .show-on-mobile-block {
    display: block;
  }

  .show-on-mobile-inline {
    display: inline;
  }
}
